@@ -7,6 +7,7 @@
 ####################################################################
 
 from mygnuhealth.__init__ import __version__ as myghver
+import os
 
 __version__ = myghver
 
@@ -25,21 +26,5 @@ __download_url__ = 'https://ftp.gnu.org/gnu/health/mygnuhealth'
 __license__ = "GPL v3+"
 __copyright__ = "Copyright 2008-2024 GNU Solidario"
 
-__thanks__ = (
-    "---- Version 2.0 (Kivy) -------\n"
-    "Axel Braun\n"
-    "Leonardo D'Acchille\n"
-    "---- Version 1.0 (PySide) -----\n"
-    "Axel Braun\n"
-    "Paul Brown\n"
-    "Yuri Chornoivan\n"
-    "Leonardo D'Acchille\n"
-    "Marco Gebhardt\n"
-    "Riccardo Iaconelli\n"
-    "Mat Knoll\n"
-    "Cristian Maureira-Fredes\n"
-    "Karl Ove Hufthammer\n"
-    "Aleix Pol\n"
-    "Carl Schwan\n"
-    "Pino Toscano\n"
-    "Niccolò Venerandi")
+__thanks__ = open(
+    os.path.join(os.path.dirname(__file__), "contributors.txt")).read()
