@@ -28,12 +28,15 @@ def test_federation_connection(protocol, host, port, acct, passwd):
 
     # Catch HTTP exceptions, including unauthorized (401) and (404)
     except requests.exceptions.HTTPError as e:
-        print(f"HTPP error: {e}")
+        print(f"HTTP error: {e}")
         login_status = -1
 
+    except BaseException as e:
+        print(f"Other errors: {e}")
+        login_status = -3
+
     if conn:
         print("***** Connection to Thalamus Server OK !******")
         login_status = 0
 
     return login_status
-
