@@ -8,6 +8,7 @@ import os
 import configparser
 from kivy.app import App
 from mygnuhealth.__init__ import __version__
+from mygnuhealth.lang import tr
 
 # Use Kivy user_data_dir to make it cross platform compatible.
 homedir = App().get_running_app().user_data_dir
@@ -23,7 +24,7 @@ bolfile = os.path.join(gh_dir, 'bol.db')
 def check_inst_dir():
     print(f"MyGNUHealth local config and db files wil go into dir: {gh_dir}")
     if os.path.isdir(gh_dir):
-        print("Directory exists... skipping")
+        print(tr._("Directory exists... skipping"))
     else:
         print("Initializing MyGNUHealth directory")
         try:
@@ -67,4 +68,3 @@ def init_mygh():
 
 
 init_mygh()
-
