@@ -28,6 +28,7 @@
 from kivy.uix.label import Label
 from kivy.uix.popup import Popup
 from mygnuhealth.core import maindb
+from mygnuhealth.lang import tr
 from mygnuhealth.fedlogin import test_federation_connection as fc
 
 
@@ -59,19 +60,21 @@ class NetworkSettings():
 
     def test_connection(protocol, *args):
         conn_res = fc(protocol, *args)
-        msg = "Unknown error"
 
         if (conn_res == 0):
-            msg = "Connection OK"
+            msg = tr._("Connection OK")
         if (conn_res == -1):
-            msg = "Invalid Credentials"
+            msg = tr._("Invalid Credentials")
         if (conn_res == -2):
-            msg = "Network Error"
+            msg = tr._("Network Error")
+        if (conn_res == -3):
+            msg = tr._("Unknown error")
 
         status_msg = f"{msg} (rc:{conn_res})"
-        popup = Popup(title='Federation Connection Status',
-                      content=Label(text=status_msg),
-                      size_hint=(0.5, 0.5), auto_dismiss=True)
+        popup = Popup(
+            title=tr._('Federation Connection Status'),
+            content=Label(text=status_msg),
+            size_hint=(0.5, 0.5), auto_dismiss=True)
         popup.open()
 
         return [conn_res, msg]
